# image_processing_on

Description.
The package image_processing_on is used to:
	Processing:
		- Histogram matching
		- Structural similarity
		- Resize image
	Utils:
		- Read image
		- Save image
		- Plot image
		- Plot result
		- Plot histogram

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

pip install image_processing_on


## Author
Maison Henrique

## License
[MIT](https://choosealicense.com/licenses/mit/)